summaryrefslogtreecommitdiff
path: root/layer.c
diff options
context:
space:
mode:
authortmk2011-02-10 15:51:30 +0900
committertmk2011-02-22 03:09:02 +0900
commit2b8cd88ab142068eed0a3f230a3de79deb567536 (patch)
treece62861e44d57791ff43391d841ea125ce319754 /layer.c
parentacc974c64b1e17e6807133fdc50de5bb34aedda5 (diff)
refactor keyboard.h, host.h
Diffstat (limited to 'layer.c')
-rw-r--r--layer.c34
1 files changed, 17 insertions, 17 deletions
diff --git a/layer.c b/layer.c
index 0e88d53d9..7138c0ed1 100644
--- a/layer.c
+++ b/layer.c
@@ -1,5 +1,5 @@
#include "keymap_skel.h"
-#include "keyboard.h"
+#include "host.h"
#include "debug.h"
#include "timer.h"
#include "layer.h"
@@ -98,23 +98,23 @@ void layer_switching(uint8_t fn_bits)
debug(" -> "); debug_hex(current_layer); debug("\n");
}
} else {
- if (keyboard_has_anykey()) { // other keys is pressed
+ if (host_has_anykey()) { // other keys is pressed
uint8_t _fn_to_send = BIT_SUBT(fn_bits, sent_fn);
if (_fn_to_send) {
debug("Fn case: 4(send Fn before other key pressed)\n");
// send only Fn key first
- keyboard_swap_report();
- keyboard_clear_report();
- keyboard_add_code(keymap_fn_keycode(_fn_to_send)); // TODO: do all Fn keys
- keyboard_set_mods(last_mods);
- keyboard_send();
- keyboard_swap_report();
+ host_swap_keyboard_report();
+ host_clear_keyboard_report();
+ host_add_code(keymap_fn_keycode(_fn_to_send)); // TODO: do all Fn keys
+ host_set_mods(last_mods);
+ host_send_keyboard_report();
+ host_swap_keyboard_report();
sent_fn |= _fn_to_send;
}
}
}
// add Fn keys to send
//keyboard_add_code(keymap_fn_keycode(fn_bits&sent_fn)); // TODO: do all Fn keys
}
} else { // Fn state is changed(edge)
uint8_t fn_changed = 0;
@@ -128,7 +128,7 @@ void layer_switching(uint8_t fn_bits)
// pressed Fn
if ((fn_changed = BIT_SUBT(fn_bits, last_fn))) {
debug("fn_changed: "); debug_bin(fn_changed); debug("\n");
- if (keyboard_has_anykey()) {
+ if (host_has_anykey()) {
debug("Fn case: 5(pressed Fn with other key)\n");
sent_fn |= fn_changed;
} else if (fn_changed & sent_fn) { // pressed same Fn in a row
@@ -149,12 +149,12 @@ void layer_switching(uint8_t fn_bits)
if (BIT_SUBT(fn_changed, sent_fn)) { // layer not used && Fn not sent
debug("Fn case: 2(send Fn one shot: released Fn during LAYER_SEND_FN_TERM)\n");
// send only Fn key first
- keyboard_swap_report();
- keyboard_clear_report();
- keyboard_add_code(keymap_fn_keycode(fn_changed)); // TODO: do all Fn keys
- keyboard_set_mods(last_mods);
- keyboard_send();
- keyboard_swap_report();
+ host_swap_keyboard_report();
+ host_clear_keyboard_report();
+ host_add_code(keymap_fn_keycode(fn_changed)); // TODO: do all Fn keys
+ host_set_mods(last_mods);
+ host_send_keyboard_report();
+ host_swap_keyboard_report();
sent_fn |= fn_changed;
}
}
@@ -171,7 +171,7 @@ void layer_switching(uint8_t fn_bits)
// send Fn keys
for (uint8_t i = 0; i < 8; i++) {
if ((sent_fn & fn_bits) & (1<<i)) {
- keyboard_add_code(keymap_fn_keycode(1<<i));
+ host_add_code(keymap_fn_keycode(1<<i));
}
}
}
@@ -98,23 +98,23 @@ void layer_switching(uint8_t fn_bits)
}
// add Fn keys to send
- //keyboard_add_code(keymap_fn_keycode(fn_bits&sent_fn)); // TODO: do all Fn keys
+ //host_add_code(keymap_fn_keycode(fn_bits&sent_fn)); // TODO: do all Fn keys
}
} else { // Fn state is changed(edge)